@@ -48,7 +48,7 @@ MB = 1024 * 1024
 GB = 1024 * MB
 TB = 1024 * GB
 
-version = '0.1.1'
+version = '0.1.2'
 
 class S3Facts:
     amz_metadata_prefix = 'x-amz-meta-'
@@ -634,7 +634,7 @@ strings uniquely identifies the file within S3.
 The S3Name class is instantiated with a key and a bucket; the key 
 is required and the bucket defaults to None.
 
-The Storage class methods take a *remote_name* argument which 
+The Storage class methods take a **remote_name** argument which 
 can be either a string which is the key, or an instance of the 
 S3Name class.  When no bucket is given (or the bucket is None) then 
 the default_bucket established when the connection is instantiated 
@@ -648,51 +648,55 @@ Headers and Metadata
 --------------------
 
 Additional http headers may be sent using the methods which write 
-data.  These methods accept an optional *headers* argument which 
+data.  These methods accept an optional **headers** argument which 
 is a python dict.  The headers control various aspects of how the 
 file may be handled.  S3 supports a variety of headers.  These are 
 not discussed here.  See Amazon's S3 documentation for more info
-on S3 headers.  Those headers whose key begins with the special 
-preifx: 'x-amz-meta-' are considered to be metadata headers and are
+on S3 headers.  
+
+Those headers whose key begins with the special prefix: 
+**x-amz-meta-** are considered to be metadata headers and are 
 used to set the metadata attributes of the file.
 
-The methods which read files also return metadata which consists of 
-only those response headers which begin with 'x-amz-meta-'.
+The methods which read files also return the metadata which 
+consists of only those response headers which begin with 
+**x-amz-meta-**.
 
 Storage Methods
 ---------------
 
-The arguments *remote_source*, *remote_destination*, and 
-*remote_name* may be either a string, or an S3Name instance.
+The arguments **remote_source**, **remote_destination**, and 
+**remote_name** may be either a string, or an S3Name instance.
 
-*local_name* is a string and is the name of the file on the local 
-system.  This string is passed directly to open().
+**local_name** is a string and is the name of the file on the 
+local system.  This string is passed directly to open().
 
-*headers* is a python dict used to encode additional request 
+**headers** is a python dict used to encode additional request 
 headers.
 
 All methods return on success or raise StorageError on failure.
 
 **storage.copy(remote_source, remote_destination, headers={})**
-    Copy *remote_source* to *remote_destination*.  The destination 
-    metadata is copied from *headers* when it contains metadata; 
-    otherwise it is copied from the source metadata.
+    Copy **remote_source** to **remote_destination**.  
+    The destination metadata is copied from **headers** when it 
+    contains metadata; otherwise it is copied from the source 
+    metadata.
 **storage.delete(remote_name)**
-    Delete *remote_name* from storage.
+    Delete **remote_name** from storage.
 **exists, metadata = storage.exists(remote_name)**
-    Test if *remote_name* exists in storage, retrieve its metadata 
-    if it does.
+    Test if **remote_name** exists in storage, retrieve its 
+    metadata if it does.
     exists - boolean, metadata - dict.
 **metadata = storage.read(remote_name, local_name)**
-    Download *remote_name* from storage, save it locally as 
-    *local_name* and retrieve its metadata.
+    Download **remote_name** from storage, save it locally as 
+    **local_name** and retrieve its metadata.
     metadata - dict.
 **storage.update_metadata(remote_name, headers)**
-    Update the metadata associated with *remote_name* with the 
-    metadata headers in *headers*.
+    Update the metadata associated with **remote_name** with the 
+    metadata headers in **headers**.
 **storage.write(local_name, remote_name, headers={})**
-    Upload *local_name* to storage as *remote_name*, and set its 
-    metadata if any metadata headers are in *headers*.
+    Upload **local_name** to storage as **remote_name**, and set 
+    its metadata if any metadata headers are in **headers**.
 """
     def __init__(self, connection, **kwargs):
         self.connection = connection
